#include "lexer.h"
#include "parser.h"
#include <gtk/gtk.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

void test_lexer_parser(void)
{
    char* text = "2 * (3 + 4)";

    Lexer lexer1;
    lexer(&lexer1, text, strlen(text));
    Token current_token = lexer_next(&lexer1);
    printf("tokens = [\n");
    while (current_token.type != TokenTypeEof) {
        char* token_string = token_to_string(&current_token, text);
        printf("    %s,\n", token_string);
        free(token_string);
        current_token = lexer_next(&lexer1);
    }
    printf("]\n");

    Lexer lexer2;
    lexer(&lexer2, text, strlen(text));
    Expr* ast = parse(&lexer2, text, strlen(text));
    char* ast_string = expr_to_string(ast);
    printf("ast = %s\n", ast_string);
    free(ast_string);
    free_expr(ast);
}

int main(int argc, char** argv)
{
    GtkWidget* window;
    GtkWidget* vbox;

    GtkWidget* menubar;
    GtkWidget* fileMenu;
    GtkWidget* fileMi;
    GtkWidget* quitMi;

    gtk_init(&argc, &argv);

    window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
    gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
    gtk_window_set_default_size(GTK_WINDOW(window), 300, 200);
    gtk_window_set_title(GTK_WINDOW(window), "Simple menu");

    vbox = gtk_vbox_new(FALSE, 0);
    gtk_container_add(GTK_CONTAINER(window), vbox);

    menubar = gtk_menu_bar_new();
    fileMenu = gtk_menu_new();

    fileMi = gtk_menu_item_new_with_label("File");
    quitMi = gtk_menu_item_new_with_label("Quit");

    gtk_menu_item_set_submenu(GTK_MENU_ITEM(fileMi), fileMenu);
    gtk_menu_shell_append(GTK_MENU_SHELL(fileMenu), quitMi);
    gtk_menu_shell_append(GTK_MENU_SHELL(menubar), fileMi);
    gtk_box_pack_start(GTK_BOX(vbox), menubar, FALSE, FALSE, 0);

    g_signal_connect(
        G_OBJECT(window), "destroy", G_CALLBACK(gtk_main_quit), NULL
    );

    g_signal_connect(
        G_OBJECT(quitMi), "activate", G_CALLBACK(gtk_main_quit), NULL
    );

    gtk_widget_show_all(window);

    gtk_main();
}
